@@ -46,6 +46,10 @@ logger = get_logger("hoss_agent")
 
 def init(config=None, *args, **inline):
 
+    global GLOBAL_CLIENT
+    if GLOBAL_CLIENT is not None:
+        logger.info('Agent already initialized. Exiting')
+        return
     if isinstance(config, str):
         if len(config) == 0 or config == 'None':
             logger.info('Hoss API Key is not provided. Exiting')
@@ -63,6 +67,5 @@ def init(config=None, *args, **inline):
 
     client.instrument()
     client.start_threads()
-    global GLOBAL_CLIENT
     GLOBAL_CLIENT = client
     return client
