@@ -265,7 +265,7 @@ class Config(_ConfigBase):
     api_key = _ConfigValue("API_KEY")
     debug = _BoolConfigValue("DEBUG", default=False)
     server_url = _ConfigValue("SERVER_URL", default="https://ingress.hoss.com", required=True)
-    config_server_url = _ConfigValue("CONFIG_SERVER_URL", default="https://app.hoss.com/api", required=True)
+    config_server_url = _ConfigValue("CONFIG_SERVER_URL", default="https://config.hoss.com/agent", required=True)
     server_cert = _ConfigValue("SERVER_CERT", default=None, required=False, validators=[FileIsReadableValidator()])
     verify_server_cert = _BoolConfigValue("VERIFY_SERVER_CERT", default=True)
     server_timeout = _ConfigValue(
