@@ -57,6 +57,8 @@ TRANSACTION = "transaction"
 SPAN = "span"
 METRICSET = "metricset"
 EVENT = "event"
+IDENTIFY = "identify"
+TRACK = "track"
 
 LABEL_RE = re.compile('[.*"]')
 HARDCODED_PROCESSORS = []
