@@ -51,6 +51,7 @@ def init(config=None, *args, **inline):
             "RequestHandler.finish", patched_finish,
         )
 
+    return client
 
 def patched_write(wrapped, instance, args, kwargs):
     """
@@ -121,6 +122,7 @@ def _get_event(request_handler):
 
     data = {
         "eventId": uuid4(),
+        "type": "IncomingHTTP",
         "request": {
             "method": request_handler.request.method,
             "headers": dict(request_handler.request.headers),
