@@ -12,11 +12,14 @@ class ReadProxy(wrapt.ObjectProxy):
 
     def read(self, amt=None):
         data = self.__wrapped__.read(amt)
-        if self.__encode:
-            self.__target__.write(data.encode("utf-8"))
-        else:
-            if isinstance(data, str):
+        try:
+            if self.__encode:
                 self.__target__.write(data.encode("utf-8"))
             else:
-                self.__target__.write(data)
+                if isinstance(data, str):
+                    self.__target__.write(data.encode("utf-8"))
+                else:
+                    self.__target__.write(data)
+        except:
+            pass
         return data
